pub struct AgentSession {
pub id: String,
pub repo_path: String,
pub snapshot_sha: Option<String>,
pub snapshot_ref: Option<String>,
pub started_at: String,
pub last_tool_at: String,
pub tool_count: u64,
}Fields
id: Stringrepo_path: StringRepository the session’s snapshot was taken in, which need not be the one currently selected — a restore has to run where the work happened.
snapshot_sha: Option<String>snapshot_ref: Option<String>started_at: Stringlast_tool_at: Stringtool_count: u64Trait Implementations
Sourceimpl Clone for AgentSession
impl Clone for AgentSession
Sourcefn clone(&self) -> AgentSession
fn clone(&self) -> AgentSession
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentSession
impl Debug for AgentSession
Sourceimpl<'de> Deserialize<'de> for AgentSession
impl<'de> Deserialize<'de> for AgentSession
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AgentSession
impl PartialEq for AgentSession
Sourceimpl Serialize for AgentSession
impl Serialize for AgentSession
impl StructuralPartialEq for AgentSession