pub async fn exec_file(
argv: &[String],
options: &ExecOptions<'_>,
) -> Result<ExecOutput, String>Expand description
The common case: a non-zero exit is a failure and the output is discarded.
pub async fn exec_file(
argv: &[String],
options: &ExecOptions<'_>,
) -> Result<ExecOutput, String>The common case: a non-zero exit is a failure and the output is discarded.