client_id

Function client_id 

pub fn client_id() -> String
Which app to authorize as. An override that trims away to nothing is not an override, so a variable set to blank behaves as if it were unset.